==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/cs.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendář",
    "%s has published the calendar \"%s\"" : "%s publikoval kalendář \"%s\"",
    "Too many redirects. Aborting ..." : "Příliš mnoho přesměrování.",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdálený server nepovolil přístup ke kalendáři (HTTP {%s} chyba)",
    "Error connecting to remote server" : "Chyba připojování ke vzdálenému serveru",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Chyba při vyžádání zdroje na vzdáleném serveru. To může být způsobeno neshodným certifikátem",
    "Error requesting resource on remote server" : "Chyba při vyžádání zdroje na vzdáleném serveru",
    "Individual" : "Individuální",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Místnost",
    "Unknown" : "Neznámý",
    "Required" : "Vyžadován",
    "Optional" : "Nepovinně",
    "Does not attend" : "Neúčastní se",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Nacházíte se v neznámé časové zóně ({tz}), použije se UTC",
    "Please create a calendar first." : "Nejdříve prosím vytvořte kalendář.",
    "New event" : "Nová událost",
    "CalDAV address for clients" : "CalDAV adresa pro klientské aplikace",
    "Error saving WebCal-calendar" : "Chyba při ukládání WebCal kalendáře",
    "WebDAV address for subscriptions" : "WebDAV adresa pro odběry",
    "EMail has been sent." : "Email byl odeslán.",
    "There was an issue while sending your EMail." : "Došlo k problému v průběhu odesílání emailu.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Připomínky",
    "Repeating" : "Opakování",
    "When shared show full event" : "Po nasdílení zobrazit celou událost",
    "When shared show only busy" : "Po nasdílení zobrazit jako zaneprázdněné",
    "When shared hide this event" : "Po nasdílení skrýt tuto událost",
    "Confirmed" : "Potvrzeno",
    "Tentative" : "Dočasně",
    "Cancelled" : "Zrušeno",
    "Please add a title!" : "Zadejte prosím název!",
    "Please select a calendar!" : "Vyberte prosím kalendář!",
    "The event ends before it starts!" : "Událosk končí dříve než začala!",
    "Global" : "Globální",
    "None" : "Žádné",
    "Every day" : "Každý den",
    "Every week" : "Každý týden",
    "Every month" : "Každý měsíc",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Co takhle začít importem nějakých kalendářů?",
    "At time of event" : "V čase události",
    "5 minutes before" : "5 minut předem",
    "10 minutes before" : "10 minut předem",
    "15 minutes before" : "15 minut předem",
    "30 minutes before" : "30 minut předem",
    "1 hour before" : "1 hodinu předem",
    "2 hours before" : "2 hodiny předem",
    "Custom" : "Vlastní",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Vyskakovací",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodiny",
    "days" : "dnech",
    "week" : "týden",
    "before" : "před",
    "start" : "začátek",
    "end" : "konec",
    "Editing reminders of unknown type not supported." : "Úprava upozornění neznámého typu není podporována.",
    "Week {number} of {year}" : "Týden {number} rok {year}",
    "Successfully imported" : "Úspěšně importován",
    "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
    "Partially imported, {n} failures" : "Částečně importován, {n} chyb",
    "Audio alarm" : "Zvuková upomínka",
    "Pop-up" : "Vyskakovací",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} před začátkem události",
    "{type} {time} before the event ends" : "{type} {time} před koncem události",
    "{type} {time} after the event starts" : "{type} {time} po začátku události",
    "{type} {time} after the event ends" : "{type} {time} po konci události",
    "{type} at the event's start" : "{type} při začátku události",
    "{type} at the event's end" : "{type} při konci události",
    "{type} at {time}" : "{type} v {time}",
    "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
    "Please enter a valid WebCal-URL" : "Zadejte prosím platnout WebCal URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Kritická chyba ve webcal proxy. Pro více informací kontaktujte svého administrátora.",
    "Title of the Event" : "Název události",
    "Starts" : "Začíná",
    "Ends" : "Končí",
    "All day Event" : "Celodenní událost",
    "Delete" : "Smazat",
    "Cancel" : "Zrušit",
    "More ..." : "Více ...",
    "Create" : "Vytvořit",
    "Update" : "Aktualizovat",
    "Close" : "Zavřít",
    "Location" : "Umístění",
    "Description" : "Popis",
    "Event status" : "Stav události",
    "Visibility when sharing" : "Viditelnost při sdílení",
    "Export" : "Exportovat",
    "%s has published the calendar %s" : "%s zveřejnil kalendář %s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chtěli jsme vás informovat, že %s zveřejnil kalendář {boldstart}%s{boldend}.",
    "Click here to access it" : "Pro přístup klikněte zde",
    "Cheers!" : "Mějte se!",
    "We wanted to inform you that %s has published the calendar %s." : "Chtěli jsme vás informovat, že %s zveřejnil kalendář %s.",
    "Click on the link below to access it" : "Pro přístup klikněte na odkaz níže",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontaktujte prosím svého administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
    "Day" : "Den",
    "Week" : "Týden",
    "Month" : "Měsíc",
    "Today" : "Dnes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "V tomto kalendáři jsou některé události poškozené. Pro více informací prosím nahlédněte do JS konzole.",
    "Share Calendar" : "Sdílet kalendář",
    "Shared" : "Sdílené",
    "More" : "Více",
    "Edit" : "Upravit",
    "Link" : "Odkaz",
    "iCal link" : "iCal odkaz",
    "Download" : "Stáhnout",
    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
    "can edit" : "lze upravovat",
    "Share link" : "Sdílet odkaz",
    "Public access" : "Veřejný přístup",
    "Email link to person" : "Odeslat odkaz emailem",
    "Send" : "Odeslat",
    "New Calendar" : "Nový kalendář",
    "Name" : "Název",
    "New Subscription" : "Nový odběr",
    "Go back" : "Jít zpět",
    "Go forward" : "Jít vpřed",
    "Calendar does not exist" : "Kalendář neexistuje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Možná máte chybný odkaz nebo kalendář nebyl sdílen?",
    "Edit event" : "Upravit událost",
    "Delete Event" : "Smazat událost",
    "Save Event" : "Uložit událost",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relativní",
    "Absolute" : "Absolutní",
    "Repeat" : "Opakovat",
    "times every" : "krát každých",
    "Add" : "Přidat",
    "E-Mail address of attendee" : "Emailová adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou emailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
    "from" : "od",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Pravidlo opakování této události není ještě podporováno.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pokročilých pravidel bude přidána v následujících aktualizacích.",
    "Reset repeating rule" : "Resetovat pravidlo opakování",
    "Repeat every ..." : "Opakovat každé ...",
    "end repeat ..." : "ukončit opakování ...",
    "times" : "krát",
    "Import Calendars" : "Importovat kalendáře",
    "Import canceled" : "Import zrušen",
    "Analyzing calendar" : "Analýza kalendáře",
    "The file contains objects incompatible with the selected calendar" : "Soubor obsahuje objekty nekompatibilní s vybraným kalendářem",
    "New calendar" : "Nový kalendář",
    "File is empty" : "Soubor je prázdný",
    "Import scheduled" : "Import načasován",
    "%s shared the calendar <strong>%s</strong> with you" : "%s sdílel(a) tento kalendář <strong>%s</strong> s tebou",
    "Embed" : "Vložit",
    "IFrame to integrate" : "Iframe k integraci",
    "Publish URL" : "Zveřejnit URL",
    "Settings & import" : "Nastavení & import",
    "Skip simple event editor" : "Přeskočit jednoduchý editor události",
    "Show week numbers" : "Zobrazit čísla týdnů",
    "Import calendar" : "Importovat kalendář",
    "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
    "Primary CalDAV address" : "Primární adresa CalDAV",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa",
    "Subscribe" : "Odebírat"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/cs.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendář",
    "%s has published the calendar »%s«" : "Osoba %s právě publikoval/a kalendář »%s«.",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozornit, že  %s právě publikoval/a  kalendář »%s«.",
    "Open »%s«" : "Otevřít »%s«",
    "Cheers!" : "Mějte se!",
    "Recipient" : "Adresát",
    "Too many redirects. Aborting ..." : "Příliš mnoho přesměrování.",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdálený server nepovolil přístup ke kalendáři (HTTP {%s} chyba)",
    "Error connecting to remote server" : "Chyba připojování ke vzdálenému serveru",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Chyba při vyžádání zdroje na vzdáleném serveru. To může být způsobeno neshodným certifikátem",
    "Error requesting resource on remote server" : "Chyba při vyžádání zdroje na vzdáleném serveru",
    "Individual" : "Individuální",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Místnost",
    "Unknown" : "Neznámý",
    "Required" : "Vyžadován",
    "Optional" : "Nepovinně",
    "Does not attend" : "Neúčastní se",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Nacházíte se v neznámé časové zóně ({tz}), použije se UTC",
    "Please create a calendar first." : "Nejdříve prosím vytvořte kalendář.",
    "New event" : "Nová událost",
    "CalDAV address for clients" : "CalDAV adresa pro klientské aplikace",
    "Error saving WebCal-calendar" : "Chyba při ukládání WebCal kalendáře",
    "WebDAV address for subscriptions" : "WebDAV adresa pro odběry",
    "Email has been sent." : "Email byl odeslán.",
    "There was an issue while sending your email." : "Došlo k problému v průběhu odesílání emailu.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Připomínky",
    "Repeating" : "Opakování",
    "When shared show full event" : "Po nasdílení zobrazit celou událost",
    "When shared show only busy" : "Po nasdílení zobrazit jako zaneprázdněné",
    "When shared hide this event" : "Po nasdílení skrýt tuto událost",
    "Confirmed" : "Potvrzeno",
    "Tentative" : "Dočasně",
    "Cancelled" : "Zrušeno",
    "Please add a title." : "Zadejte prosím název.",
    "Please select a calendar." : "Vyberte prosím kalendář.",
    "The event can not end before it starts." : "Událost končí dříve než začala.",
    "Global" : "Globální",
    "None" : "Žádné",
    "Every day" : "Každý den",
    "Every week" : "Každý týden",
    "Every month" : "Každý měsíc",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Co takhle začít importem nějakých kalendářů?",
    "At time of event" : "V čase události",
    "5 minutes before" : "5 minut předem",
    "10 minutes before" : "10 minut předem",
    "15 minutes before" : "15 minut předem",
    "30 minutes before" : "30 minut předem",
    "1 hour before" : "1 hodinu předem",
    "2 hours before" : "2 hodiny předem",
    "Custom" : "Vlastní",
    "Audio" : "Audio",
    "Email" : "Email",
    "Pop-up" : "Vyskakovací",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodiny",
    "days" : "dnech",
    "week" : "týden",
    "before" : "před",
    "start" : "začátek",
    "end" : "konec",
    "Editing reminders of unknown type not supported." : "Úprava upozornění neznámého typu není podporována.",
    "Week {number} of {year}" : "Týden {number} rok {year}",
    "Successfully imported" : "Úspěšně importován",
    "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
    "Partially imported, {n} failures" : "Částečně importován, {n} chyb",
    "Audio alarm" : "Zvuková upomínka",
    "{type} {time} before the event starts" : "{type} {time} před začátkem události",
    "{type} {time} before the event ends" : "{type} {time} před koncem události",
    "{type} {time} after the event starts" : "{type} {time} po začátku události",
    "{type} {time} after the event ends" : "{type} {time} po konci události",
    "{type} at the event's start" : "{type} při začátku události",
    "{type} at the event's end" : "{type} při konci události",
    "{type} at {time}" : "{type} v {time}",
    "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
    "Please enter a valid WebCal-URL" : "Zadejte prosím platnout WebCal URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Kritická chyba ve webcal proxy. Pro více informací kontaktujte svého administrátora.",
    "Title of the Event" : "Název události",
    "Starts" : "Začíná",
    "Ends" : "Končí",
    "All day Event" : "Celodenní událost",
    "Delete" : "Smazat",
    "Cancel" : "Zrušit",
    "More ..." : "Více ...",
    "Create" : "Vytvořit",
    "Update" : "Aktualizovat",
    "Close" : "Zavřít",
    "Location" : "Umístění",
    "Description" : "Popis",
    "Event status" : "Stav události",
    "Visibility when sharing" : "Viditelnost při sdílení",
    "Export" : "Exportovat",
    "%s has published the calendar %s" : "%s zveřejnil kalendář %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chtěli jsme vás informovat, že %s zveřejnil kalendář {boldstart}%s{boldend}.",
    "Click here to access it" : "Pro přístup klikněte zde",
    "We wanted to inform you that %s has published the calendar %s." : "Chtěli jsme vás informovat, že %s zveřejnil kalendář %s.",
    "Click on the link below to access it" : "Pro přístup klikněte na odkaz níže",
    "Day" : "Den",
    "Week" : "Týden",
    "Month" : "Měsíc",
    "Today" : "Dnes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "V tomto kalendáři jsou některé události poškozené. Pro více informací prosím nahlédněte do JS konzole.",
    "Share Calendar" : "Sdílet kalendář",
    "Shared" : "Sdílené",
    "More" : "Více",
    "Edit" : "Upravit",
    "Link" : "Odkaz",
    "iCal link" : "iCal odkaz",
    "Download" : "Stáhnout",
    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
    "can edit" : "lze upravovat",
    "Share link" : "Sdílet odkaz",
    "Public access" : "Veřejný přístup",
    "Email link to person" : "Odeslat odkaz emailem",
    "Send" : "Odeslat",
    "New Calendar" : "Nový kalendář",
    "Name" : "Název",
    "New Subscription" : "Nový odběr",
    "Go back" : "Jít zpět",
    "Go forward" : "Jít vpřed",
    "Calendar does not exist" : "Kalendář neexistuje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Možná máte chybný odkaz nebo kalendář nebyl sdílen?",
    "Edit event" : "Upravit událost",
    "Delete Event" : "Smazat událost",
    "Save Event" : "Uložit událost",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relativní",
    "Absolute" : "Absolutní",
    "Repeat" : "Opakovat",
    "times every" : "krát každých",
    "Add" : "Přidat",
    "Email address of attendee" : "Emailová adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou emailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
    "from" : "od",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Pravidlo opakování této události není ještě podporováno.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pokročilých pravidel bude přidána v následujících aktualizacích.",
    "Reset repeating rule" : "Resetovat pravidlo opakování",
    "Repeat every ..." : "Opakovat každé ...",
    "end repeat ..." : "ukončit opakování ...",
    "times" : "krát",
    "Import Calendars" : "Importovat kalendáře",
    "Import canceled" : "Import zrušen",
    "Analyzing calendar" : "Analýza kalendáře",
    "The file contains objects incompatible with the selected calendar" : "Soubor obsahuje objekty nekompatibilní s vybraným kalendářem",
    "New calendar" : "Nový kalendář",
    "File is empty" : "Soubor je prázdný",
    "Import scheduled" : "Import načasován",
    "%s shared the calendar <strong>%s</strong> with you" : "%s sdílel(a) tento kalendář <strong>%s</strong> s tebou",
    "Embed" : "Vložit",
    "Iframe to integrate" : "Iframe k integraci",
    "Publish URL" : "Zveřejnit URL",
    "Settings & import" : "Nastavení & import",
    "Skip simple event editor" : "Přeskočit jednoduchý editor události",
    "Show week numbers" : "Zobrazit čísla týdnů",
    "Import calendar" : "Importovat kalendář",
    "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
    "Primary CalDAV address" : "Primární adresa CalDAV",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa",
    "Subscribe" : "Odebírat"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
